| as.vmr | R Documentation |
The vmr class wraps the mr class using the vctrs package, for compatibility with tidyverse tbl_df objects (tibbles).
as.vmr(x, ...)
new_vmr(x, levels = unique(do.call(c, x)))
x |
For |
... |
not used |
levels |
the permitted levels for the object |
These objects need the vctrs and pillar packages to work, and need the tibble package to be useful.
An object of class vmr
as.mr
The internals vignette for internal structure
if (requireNamespace("vctrs", quietly=TRUE)){
data(nzbirds)
nzbirds
tidybirds<-as.vmr(nzbirds, na.rm=TRUE)
tidybirds
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.