Learn R Programming

rimu (version 0.6)

birds: Subset of the Great Backyard Bird survey

Description

Counts of observations for 12 bird species by US county and Canadian province in the Great Backyard Bird survey. These birds were randomly sampled from the much larger number in the full data set. See the vignette for more details.

Usage

data("birds")

Arguments

Format

A data frame with 3046 observations on the following 13 variables.

Phalaenoptilus nuttallii

a numeric vector

Fregata magnificens

a numeric vector

Melanerpes lewis

a numeric vector

Melospiza georgiana

a numeric vector

Rallus limicola

a numeric vector

Myioborus pictus

a numeric vector

Poecile gambeli

a numeric vector

Aythya collaris

a numeric vector

Xanthocephalus xanthocephalus

a numeric vector

Gracula religiosa

a numeric vector

Icterus parisorum

a numeric vector

Coccyzus erythropthalmus

a numeric vector

location

a character vector

Examples

Run this code
data(birds)
birds<-as.ms(birds[,1:12],na.rm=TRUE)
mtable(as.mr(birds))

Run the code above in your browser using DataLab