| mrequal | R Documentation |
Returns vector of TRUE or FALSE according to whether y is onle of the levels present for that row or is the only level present for that row.
x %has% y
x %hasonly% y
x %hasall% ys
x %hasany% ys
x |
|
y |
character vector specifying a level |
ys |
character vector specifying one or more levels |
Logical vector
data(ethnicity)
ethnicity
ethnicity %has% "Maori"
ethnicity %hasonly% "Maori"
data(nzbirds)
as.mr(nzbirds)
as.mr(nzbirds)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.