powered by
The vmr class wraps the mr class using the vctrs package, for compatibility with tidyverse tbl_df objects (tibbles).
vmr
mr
vctrs
tbl_df
as.vmr(x, ...) new_vmr(x, levels = unique(do.call(c, x)))
An object of class vmr
For as.vmr, an mr object or anything coercible to one. For new_vmr, a list of character vectors
as.vmr
new_vmr
not used
the permitted levels for the object
These objects need the vctrs and pillar packages to work, and need the tibble package to be useful.
pillar
tibble
as.mr
The internals vignette for internal structure
internals
if (requireNamespace("vctrs", quietly=TRUE)){ data(nzbirds) nzbirds tidybirds<-as.vmr(nzbirds, na.rm=TRUE) tidybirds }
Run the code above in your browser using DataLab