mr_inorder: Reorder levels of multiple-response objects
Description
mr_inorder and ms_inorder use the order in which the
levels first appear in the data (which is invariant to locale),mr_inseq and
ms_inseq sort alphabetically (for the current locale). mr_infreq sorts by frequency, and ms_inscore applies a function to the values in each level -- one such function is mean0, which takes the mean of non-zero values. Finally, ms_reorder and mr_reorder use some function of a second variable computed on the observations where each level is present.